# Tarrian

**Tarrian** adalah pengelola instalasi dan pembaruan Bahasa Tarri.

---

## Fitur

- Memeriksa lingkungan sistem.
- Instalasi Bahasa Tarri beserta dependensinya.
- Perbarui Bahasa Tarri otomatis.
- Hapus instalasi Bahasa Tarri.
- Support Windows, macOS, dan Linux

---

## Instalasi

Pastikan sudah punya **Python 3.9+** dan **pip**.

```bash
pip install --index-url https://test.pypi.org/simple/ tarrian
```


## Perintah penggunaan

# Cek lingkungan
```bash
tarrian cek
```

# Instal Tarri
```bash
tarrian pasang tarri
```

# Perbarui Tarri
```bash
tarrian perbarui tarri
```

# Hapus Tarri
```bash
tarrian hapus tarri
```

# Tampilkan versi Tarrian
```bash
tarrian -v
```


## Kontak
Bisa kirim email untuk informasi lainnya ke 

# bahasa.tarri@gmail.com

